@@ -3,17 +3,20 @@ from luckydonaldUtils.encoding import unicode_type, to_unicode as u
 from luckydonaldUtils.exceptions import assert_type_or_raise
 from . import Sendable
 
-__all__ = ['PassportElementError', 'PassportElementErrorDataField', 'PassportElementErrorFrontSide', 'PassportElementErrorReverseSide', 'PassportElementErrorSelfie', 'PassportElementErrorFile', 'PassportElementErrorFiles']
 __author__ = 'luckydonald'
 
 
 class PassportElementError(Sendable):
     """
-    This object represents an error in the Telegram Passport element
-    which was submitted that should be resolved by the user.
+    This object represents an error in the Telegram Passport element which was submitted that should be resolved by the user.
+
+    https://core.telegram.org/bots/api#inputmedia
+
+    Optional keyword parameters:
     """
+
     pass
-# end class
+# end class PassportElementError
 
 
 class PassportElementErrorDataField(PassportElementError):
@@ -21,86 +24,84 @@ class PassportElementErrorDataField(PassportElementError):
     Represents an issue in one of the data fields that was provided by the user. The error is considered resolved when the field's value changes.
 
     https://core.telegram.org/bots/api#passportelementerrordatafield
-
+    
 
     Parameters:
-
-    :param source: Error source, must be data
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the error, one of “personal_details”, “passport”, “driver_license”, “identity_card”, “internal_passport”, “address”
+    
+    :param type: The section of the user's Telegram Passport which has the error, one of "personal_details", "passport", "driver_license", "identity_card", "internal_passport", "address"
     :type  type: str|unicode
-
+    
     :param field_name: Name of the data field which has the error
     :type  field_name: str|unicode
-
+    
     :param data_hash: Base64-encoded data hash
     :type  data_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, field_name, data_hash, message):
+    def __init__(self, type, field_name, data_hash, message):
         """
         Represents an issue in one of the data fields that was provided by the user. The error is considered resolved when the field's value changes.
 
         https://core.telegram.org/bots/api#passportelementerrordatafield
-
+        
 
         Parameters:
-
-        :param source: Error source, must be data
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the error, one of “personal_details”, “passport”, “driver_license”, “identity_card”, “internal_passport”, “address”
+        
+        :param type: The section of the user's Telegram Passport which has the error, one of "personal_details", "passport", "driver_license", "identity_card", "internal_passport", "address"
         :type  type: str|unicode
-
+        
         :param field_name: Name of the data field which has the error
         :type  field_name: str|unicode
-
+        
         :param data_hash: Base64-encoded data hash
         :type  data_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorDataField, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'data'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(field_name, unicode_type, parameter_name="field_name")
         self.field_name = field_name
-
         assert_type_or_raise(data_hash, unicode_type, parameter_name="data_hash")
         self.data_hash = data_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorDataField to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorDataField, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['field_name'] = u(self.field_name)  # py2: type unicode, py3: type str
         array['data_hash'] = u(self.data_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -175,76 +176,75 @@ class PassportElementErrorFrontSide(PassportElementError):
     Represents an issue with the front side of a document. The error is considered resolved when the file with the front side of the document changes.
 
     https://core.telegram.org/bots/api#passportelementerrorfrontside
-
+    
 
     Parameters:
-
-    :param source: Error source, must be front_side
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”
+    
+    :param type: The section of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport"
     :type  type: str|unicode
-
+    
     :param file_hash: Base64-encoded hash of the file with the front side of the document
     :type  file_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hash, message):
+    def __init__(self, type, file_hash, message):
         """
         Represents an issue with the front side of a document. The error is considered resolved when the file with the front side of the document changes.
 
         https://core.telegram.org/bots/api#passportelementerrorfrontside
-
+        
 
         Parameters:
-
-        :param source: Error source, must be front_side
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”
+        
+        :param type: The section of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport"
         :type  type: str|unicode
-
+        
         :param file_hash: Base64-encoded hash of the file with the front side of the document
         :type  file_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorFrontSide, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'front_side'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hash, unicode_type, parameter_name="file_hash")
         self.file_hash = file_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorFrontSide to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorFrontSide, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hash'] = u(self.file_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -262,7 +262,7 @@ class PassportElementErrorFrontSide(PassportElementError):
         data['type'] = u(array.get('type'))
         data['file_hash'] = u(array.get('file_hash'))
         data['message'] = u(array.get('message'))
-
+        return data
     # end def validate_array
 
     @staticmethod
@@ -318,76 +318,75 @@ class PassportElementErrorReverseSide(PassportElementError):
     Represents an issue with the reverse side of a document. The error is considered resolved when the file with reverse side of the document changes.
 
     https://core.telegram.org/bots/api#passportelementerrorreverseside
-
+    
 
     Parameters:
-
-    :param source: Error source, must be reverse_side
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the issue, one of “driver_license”, “identity_card”
+    
+    :param type: The section of the user's Telegram Passport which has the issue, one of "driver_license", "identity_card"
     :type  type: str|unicode
-
+    
     :param file_hash: Base64-encoded hash of the file with the reverse side of the document
     :type  file_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hash, message):
+    def __init__(self, type, file_hash, message):
         """
         Represents an issue with the reverse side of a document. The error is considered resolved when the file with reverse side of the document changes.
 
         https://core.telegram.org/bots/api#passportelementerrorreverseside
-
+        
 
         Parameters:
-
-        :param source: Error source, must be reverse_side
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the issue, one of “driver_license”, “identity_card”
+        
+        :param type: The section of the user's Telegram Passport which has the issue, one of "driver_license", "identity_card"
         :type  type: str|unicode
-
+        
         :param file_hash: Base64-encoded hash of the file with the reverse side of the document
         :type  file_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorReverseSide, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'reverse_side'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hash, unicode_type, parameter_name="file_hash")
         self.file_hash = file_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorReverseSide to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorReverseSide, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hash'] = u(self.file_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -461,76 +460,75 @@ class PassportElementErrorSelfie(PassportElementError):
     Represents an issue with the selfie with a document. The error is considered resolved when the file with the selfie changes.
 
     https://core.telegram.org/bots/api#passportelementerrorselfie
-
+    
 
     Parameters:
-
-    :param source: Error source, must be selfie
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”
+    
+    :param type: The section of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport"
     :type  type: str|unicode
-
+    
     :param file_hash: Base64-encoded hash of the file with the selfie
     :type  file_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hash, message):
+    def __init__(self, type, file_hash, message):
         """
         Represents an issue with the selfie with a document. The error is considered resolved when the file with the selfie changes.
 
         https://core.telegram.org/bots/api#passportelementerrorselfie
-
+        
 
         Parameters:
-
-        :param source: Error source, must be selfie
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”
+        
+        :param type: The section of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport"
         :type  type: str|unicode
-
+        
         :param file_hash: Base64-encoded hash of the file with the selfie
         :type  file_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorSelfie, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'selfie'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hash, unicode_type, parameter_name="file_hash")
         self.file_hash = file_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorSelfie to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorSelfie, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hash'] = u(self.file_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -604,76 +602,75 @@ class PassportElementErrorFile(PassportElementError):
     Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.
 
     https://core.telegram.org/bots/api#passportelementerrorfile
-
+    
 
     Parameters:
-
-    :param source: Error source, must be file
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the issue, one of “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+    
+    :param type: The section of the user's Telegram Passport which has the issue, one of "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
     :type  type: str|unicode
-
+    
     :param file_hash: Base64-encoded file hash
     :type  file_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hash, message):
+    def __init__(self, type, file_hash, message):
         """
         Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.
 
         https://core.telegram.org/bots/api#passportelementerrorfile
-
+        
 
         Parameters:
-
-        :param source: Error source, must be file
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the issue, one of “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+        
+        :param type: The section of the user's Telegram Passport which has the issue, one of "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
         :type  type: str|unicode
-
+        
         :param file_hash: Base64-encoded file hash
         :type  file_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorFile, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'file'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hash, unicode_type, parameter_name="file_hash")
         self.file_hash = file_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorFile to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorFile, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hash'] = u(self.file_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -747,76 +744,75 @@ class PassportElementErrorFiles(PassportElementError):
     Represents an issue with a list of scans. The error is considered resolved when the list of files containing the scans changes.
 
     https://core.telegram.org/bots/api#passportelementerrorfiles
-
+    
 
     Parameters:
-
-    :param source: Error source, must be files
-    :type  source: str|unicode
-
-    :param type: The section of the user's Telegram Passport which has the issue, one of “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+    
+    :param type: The section of the user's Telegram Passport which has the issue, one of "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
     :type  type: str|unicode
-
+    
     :param file_hashes: List of base64-encoded file hashes
     :type  file_hashes: list of str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hashes, message):
+    def __init__(self, type, file_hashes, message):
         """
         Represents an issue with a list of scans. The error is considered resolved when the list of files containing the scans changes.
 
         https://core.telegram.org/bots/api#passportelementerrorfiles
-
+        
 
         Parameters:
-
-        :param source: Error source, must be files
-        :type  source: str|unicode
-
-        :param type: The section of the user's Telegram Passport which has the issue, one of “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+        
+        :param type: The section of the user's Telegram Passport which has the issue, one of "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
         :type  type: str|unicode
-
+        
         :param file_hashes: List of base64-encoded file hashes
         :type  file_hashes: list of str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorFiles, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'files'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hashes, list, parameter_name="file_hashes")
         self.file_hashes = file_hashes
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorFiles to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorFiles, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hashes'] = self._as_array(self.file_hashes)  # type list of str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -890,78 +886,73 @@ class PassportElementErrorTranslationFile(PassportElementError):
     Represents an issue with one of the files that constitute the translation of a document. The error is considered resolved when the file changes.
 
     https://core.telegram.org/bots/api#passportelementerrortranslationfile
-
+    
 
     Parameters:
-
-    :param source: Error source, must be translation_file
-    :type  source: str|unicode
-
-    :param type: Type of element of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+    
+    :param type: Type of element of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport", "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
     :type  type: str|unicode
-
+    
     :param file_hash: Base64-encoded file hash
     :type  file_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hash, message):
+    def __init__(self, type, file_hash, message):
         """
         Represents an issue with one of the files that constitute the translation of a document. The error is considered resolved when the file changes.
 
         https://core.telegram.org/bots/api#passportelementerrortranslationfile
-
+        
 
         Parameters:
-
-        :param source: Error source, must be translation_file
-        :type  source: str|unicode
-
-        :param type: Type of element of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+        
+        :param type: Type of element of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport", "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
         :type  type: str|unicode
-
+        
         :param file_hash: Base64-encoded file hash
         :type  file_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorTranslationFile, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'translation_file'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hash, unicode_type, parameter_name="file_hash")
         self.file_hash = file_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorTranslationFile to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorTranslationFile, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
-
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
-
         array['file_hash'] = u(self.file_hash)  # py2: type unicode, py3: type str
-
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
 
         return array
@@ -1037,76 +1028,75 @@ class PassportElementErrorTranslationFiles(PassportElementError):
     Represents an issue with the translated version of a document. The error is considered resolved when a file with the document translation change.
 
     https://core.telegram.org/bots/api#passportelementerrortranslationfiles
-
+    
 
     Parameters:
-
-    :param source: Error source, must be translation_files
-    :type  source: str|unicode
-
-    :param type: Type of element of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+    
+    :param type: Type of element of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport", "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
     :type  type: str|unicode
-
+    
     :param file_hashes: List of base64-encoded file hashes
     :type  file_hashes: list of str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, file_hashes, message):
+    def __init__(self, type, file_hashes, message):
         """
         Represents an issue with the translated version of a document. The error is considered resolved when a file with the document translation change.
 
         https://core.telegram.org/bots/api#passportelementerrortranslationfiles
-
+        
 
         Parameters:
-
-        :param source: Error source, must be translation_files
-        :type  source: str|unicode
-
-        :param type: Type of element of the user's Telegram Passport which has the issue, one of “passport”, “driver_license”, “identity_card”, “internal_passport”, “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
+        
+        :param type: Type of element of the user's Telegram Passport which has the issue, one of "passport", "driver_license", "identity_card", "internal_passport", "utility_bill", "bank_statement", "rental_agreement", "passport_registration", "temporary_registration"
         :type  type: str|unicode
-
+        
         :param file_hashes: List of base64-encoded file hashes
         :type  file_hashes: list of str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorTranslationFiles, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'translation_files'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(file_hashes, list, parameter_name="file_hashes")
         self.file_hashes = file_hashes
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorTranslationFiles to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorTranslationFiles, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['file_hashes'] = self._as_array(self.file_hashes)  # type list of str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -1180,76 +1170,75 @@ class PassportElementErrorUnspecified(PassportElementError):
     Represents an issue in an unspecified place. The error is considered resolved when new data is added.
 
     https://core.telegram.org/bots/api#passportelementerrorunspecified
-
+    
 
     Parameters:
-
-    :param source: Error source, must be unspecified
-    :type  source: str|unicode
-
+    
     :param type: Type of element of the user's Telegram Passport which has the issue
     :type  type: str|unicode
-
+    
     :param element_hash: Base64-encoded element hash
     :type  element_hash: str|unicode
-
+    
     :param message: Error message
     :type  message: str|unicode
-
+    
 
     Optional keyword parameters:
     """
 
-    def __init__(self, source, type, element_hash, message):
+    def __init__(self, type, element_hash, message):
         """
         Represents an issue in an unspecified place. The error is considered resolved when new data is added.
 
         https://core.telegram.org/bots/api#passportelementerrorunspecified
-
+        
 
         Parameters:
-
-        :param source: Error source, must be unspecified
-        :type  source: str|unicode
-
+        
         :param type: Type of element of the user's Telegram Passport which has the issue
         :type  type: str|unicode
-
+        
         :param element_hash: Base64-encoded element hash
         :type  element_hash: str|unicode
-
+        
         :param message: Error message
         :type  message: str|unicode
-
+        
 
         Optional keyword parameters:
         """
         super(PassportElementErrorUnspecified, self).__init__()
-        assert_type_or_raise(source, unicode_type, parameter_name="source")
-        self.source = source
-
+        self.source = 'unspecified'
         assert_type_or_raise(type, unicode_type, parameter_name="type")
         self.type = type
-
         assert_type_or_raise(element_hash, unicode_type, parameter_name="element_hash")
         self.element_hash = element_hash
-
         assert_type_or_raise(message, unicode_type, parameter_name="message")
         self.message = message
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this PassportElementErrorUnspecified to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(PassportElementErrorUnspecified, self).to_array()
+        
         array['source'] = u(self.source)  # py2: type unicode, py3: type str
         array['type'] = u(self.type)  # py2: type unicode, py3: type str
         array['element_hash'] = u(self.element_hash)  # py2: type unicode, py3: type str
         array['message'] = u(self.message)  # py2: type unicode, py3: type str
+
         return array
     # end def to_array
 
@@ -1316,3 +1305,4 @@ class PassportElementErrorUnspecified(PassportElementError):
         )
     # end def __contains__
 # end class PassportElementErrorUnspecified
+
