@@ -11,49 +11,64 @@ class LabeledPrice(Sendable):
     This object represents a portion of the price for goods or services.
 
     https://core.telegram.org/bots/api#labeledprice
-
+    
 
     Parameters:
-
+    
     :param label: Portion label
     :type  label: str|unicode
-
+    
     :param amount: Price of the product in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
     :type  amount: int
+    
+
+    Optional keyword parameters:
     """
+
     def __init__(self, label, amount):
         """
         This object represents a portion of the price for goods or services.
 
         https://core.telegram.org/bots/api#labeledprice
-
+        
 
         Parameters:
-
+        
         :param label: Portion label
         :type  label: str|unicode
-
+        
         :param amount: Price of the product in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
         :type  amount: int
+        
+
+        Optional keyword parameters:
         """
         super(LabeledPrice, self).__init__()
         assert_type_or_raise(label, unicode_type, parameter_name="label")
         self.label = label
-
         assert_type_or_raise(amount, int, parameter_name="amount")
         self.amount = amount
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this LabeledPrice to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(LabeledPrice, self).to_array()
+        
         array['label'] = u(self.label)  # py2: type unicode, py3: type str
         array['amount'] = int(self.amount)  # type int
+
         return array
     # end def to_array
 
@@ -125,18 +140,21 @@ class ShippingOption(Sendable):
     This object represents one shipping option.
 
     https://core.telegram.org/bots/api#shippingoption
-
+    
 
     Parameters:
-
+    
     :param id: Shipping option identifier
     :type  id: str|unicode
-
+    
     :param title: Option title
     :type  title: str|unicode
-
+    
     :param prices: List of price portions
     :type  prices: list of pytgbot.api_types.sendable.payments.LabeledPrice
+    
+
+    Optional keyword parameters:
     """
 
     def __init__(self, id, title, prices):
@@ -144,42 +162,52 @@ class ShippingOption(Sendable):
         This object represents one shipping option.
 
         https://core.telegram.org/bots/api#shippingoption
-
+        
 
         Parameters:
-
+        
         :param id: Shipping option identifier
         :type  id: str|unicode
-
+        
         :param title: Option title
         :type  title: str|unicode
-
+        
         :param prices: List of price portions
         :type  prices: list of pytgbot.api_types.sendable.payments.LabeledPrice
+        
+
+        Optional keyword parameters:
         """
         super(ShippingOption, self).__init__()
-
+        
         assert_type_or_raise(id, unicode_type, parameter_name="id")
         self.id = id
-
         assert_type_or_raise(title, unicode_type, parameter_name="title")
         self.title = title
-
         assert_type_or_raise(prices, list, parameter_name="prices")
         self.prices = prices
     # end def __init__
 
-    def to_array(self):
+    def to_array(self, prefer_original=False):
         """
         Serializes this ShippingOption to a dictionary.
 
+        :param prefer_original: If we should return the data this was constructed with if available. If it's not available, it will be constructed normally from the data of the object.
+        :type  prefer_original: bool
+
         :return: dictionary representation of this object.
         :rtype: dict
         """
+        if prefer_original and self._raw:
+            return self._raw
+        # end if
+
         array = super(ShippingOption, self).to_array()
+        
         array['id'] = u(self.id)  # py2: type unicode, py3: type str
         array['title'] = u(self.title)  # py2: type unicode, py3: type str
         array['prices'] = self._as_array(self.prices)  # type list of LabeledPrice
+
         return array
     # end def to_array
 
@@ -192,7 +220,7 @@ class ShippingOption(Sendable):
         :rtype: dict
         """
         assert_type_or_raise(array, dict, parameter_name="array")
-
+        
         data = Sendable.validate_array(array)
         data['id'] = u(array.get('id'))
         data['title'] = u(array.get('title'))
@@ -246,3 +274,4 @@ class ShippingOption(Sendable):
         )
     # end def __contains__
 # end class ShippingOption
+
